DefaultApplication (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Class DefaultApplication

- java.lang.Object
- - py4j.DefaultApplication

-     public class DefaultApplication
      extends java.lang.Object

  Default application that can be used to quickly test Py4J.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `DefaultApplication()`

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static void` | `main(java.lang.String[] args)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### DefaultApplication

          public DefaultApplication()

  - ### Method Detail

    - #### main

          public static void main(java.lang.String[] args)

      Parameters:
        `args` -